Версии
======

0.5.7
-------

* "news" URL removed

0.5.6
-------

* When creating article categories and articles, the uniqueness of two fields is now taken into account: language and slug


0.5.5
-------

Added translation into English for the admin panel
